@@ -30,8 +30,9 @@ class ClassRecord:
         self.name = name
         self.methods = list(methods)
         self.attributes = list(attributes)
-        self.bases = list(bases)
+        self.bases: list[FakeAnnotation] = list(bases)
         self.use_alias = use_alias
+        self.docstring = ""
 
     @property
     def boto3_doc_link(self) -> str:
@@ -40,13 +41,6 @@ class ClassRecord:
         """
         return ""
 
-    @property
-    def docstring(self) -> str:
-        """
-        Class docstring.
-        """
-        return ""
-
     @property
     def alias_name(self) -> str:
         """
